# ficamp

> Analyze your bank data and categorize it.

This has been a [PyCamp.es](https://pycamp.es) 2024 project, use with discretion.

## Installation

```sh
pipx install ficamp
```

Alternatively:

```sh
pip install -U --user ficamp
```

## Usage

```terminal
$ ficamp --help
usage: ficamp [-h] [--bank {abn}] filename

Print the first argument from the CLI

positional arguments:
  filename      The spreadsheet to load

options:
  -h, --help    show this help message and exit
  --bank {abn}
```

## Contributing

Read [CONTRIBUTING.md](./CONTRIBUTING.md).